@@ -343,7 +343,7 @@ age.PD <- function(x,nuclide,isochron=TRUE,i2i=TRUE,exterr=TRUE,i=NA,
 # tt and st are the age and error (scalars produced by peakfit or weightedmean)
 # calculated without taking into account the external errors
 add.exterr <- function(x,tt,st,cutoff.76=1100,type=4){
-    out <- c(0,0)
+    out <- c(tt,st)
     if (hasClass(x,'UPb')){
         if (type==1){
             R <- age_to_Pb207U235_ratio(tt,st)
