@@ -44,15 +44,15 @@
 #'     degrees of freedom}
 #'
 #'     }
-#' @seealso \code{\link{york}}, \code{\link{isochron}}, \code{\link{ludwig}}
-#' @references
-#' Titterington, D.M. and Halliday, A.N., 1979. On the fitting of
-#' parallel isochrons and the method of maximum likelihood. Chemical
-#' Geology, 26(3), pp.183-195.
+#' @seealso \code{\link{data2york}}, \code{\link{titterington}},
+#'     \code{\link{isochron}}, \code{\link{ludwig}}
+#' @references Titterington, D.M. and Halliday, A.N., 1979. On the
+#'     fitting of parallel isochrons and the method of maximum
+#'     likelihood. Chemical Geology, 26(3), pp.183-195.
 #'
-#' York, Derek, et al. "Unified equations for the slope,
-#' intercept, and standard errors of the best straight line."
-#' American Journal of Physics 72.3 (2004): 367-375.
+#' York, Derek, et al., 2004. Unified equations for the slope,
+#' intercept, and standard errors of the best straight line.  American
+#' Journal of Physics 72.3, pp.367-375.
 #'
 #' @examples
 #'    X <- c(1.550,12.395,20.445,20.435,20.610,24.900,
@@ -164,8 +164,62 @@ get.york.xy <- function(x,a,b){
     out
 }
 
+#' Prepare geochronological data for York regression
+#'
+#' Takes geochronology data as input and produces a
+#' five-column table as output, which can be used
+#' for York regression.
+#'
+#' @param x a five or six column matrix OR an object of class
+#'     \code{UPb}, \code{PbPb}, \code{ArAr}, \code{ThU}, \code{UThHe},
+#'     or \code{PD} (which includes objects of class \code{RbSr},
+#'     \code{SmNd}, \code{LuHf} and \code{ReOs}), generated by the
+#'     \code{read.data(...)} function
+#' @param format one of
+#'
+#' 1. \code{X}, \code{s[X]}, \code{Y}, \code{s[Y]}, \code{rho}
+#'
+#' where \code{rho} is the error correlation between \code{X} and
+#' \code{Y}, or
+#'
+#' 2. \code{X/Z}, \code{s[X/Z]}, \code{Y/Z}, \code{s[Y/Z]},
+#' \code{X/Y}, \code{s[X/Y]} for which the error correlations are
+#' automatically computed from the redundancy of the three ratios.
+#'
+#' @param ... optional arguments
+#' @return a five-column table that can be used as input for
+#'     \code{\link{york}}-regression.
+#' @examples
+#' f <- system.file("RbSr1.csv",package="IsoplotR")
+#' dat <- read.csv(f)
+#' yorkdat <- data2york(dat)
+#' fit <- york(yorkdat)
+#' @seealso \code{\link{york}}
+#' @rdname data2york
+#' @export
 data2york <- function(x,...){ UseMethod("data2york",x) }
-data2york.default <- function(x,...){ stop('default function undefined') }
+#' @rdname data2york
+#' @export
+data2york.default <- function(x,format=1,...){
+    if (format==1){
+        out <- read.XsXYsYrXY(x)
+    } else {
+        out <- cbind(x[,1:4],get.cor.div(x[,1],x[,2],x[,3],
+                                         x[,4],x[,5],x[,6]))
+    }
+    colnames(out) <- c('X','sX','Y','sY','rXY')
+    out
+}
+#' @param wetherill If \code{TRUE}, returns a table with \code{X=7/5},
+#'     \code{sX=s[7/5]}, \code{Y=6/8}, \code{sY=s[6/8]},
+#'     \code{rXY}
+#'
+#' If \code{FALSE}, returns a table with \code{X=8/6},
+#'     \code{sX=s[8/6]}, \code{Y=7/6}, \code{sY=s[7/6]},
+#'     \code{rho=rXY}
+#'
+#' @rdname data2york
+#' @export
 data2york.UPb <- function(x,wetherill=TRUE,...){
     ns <- length(x)
     out <- matrix(0,ns,5)
@@ -202,6 +256,27 @@ data2york.UPb <- function(x,wetherill=TRUE,...){
     colnames(out) <- c('X','sX','Y','sY','rXY')
     out
 }
+
+#' @param inverse If \code{x} has class \code{ArAr} and
+#'     \code{inverse=FALSE}, returns a table with columns
+#'     \code{X=9/6}, \code{sX=s[9/6]}, \code{Y=0/6}, code{sY=s[0/6]},
+#'     \code{rXY}
+#'
+#' If \code{x} has class \code{ArAr} and \code{inverse=TRUE}, returns
+#'     a table with columns \code{X=9/0}, \code{sX=s[9/0]},
+#'     \code{Y=6/0}, code{sY=s[6/0]}, \code{rXY}
+#' 
+#' If \code{x} has class \code{PbPb} and
+#'     \code{inverse=FALSE}, returns a table with columns
+#'     \code{X=6/4}, \code{sX=s[6/4]}, \code{Y=7/4}, code{sY=s[7/4]},
+#'     \code{rXY}
+#'
+#' If \code{x} has class \code{PbPb} and \code{inverse=TRUE}, returns
+#'     a table with columns \code{X=4/6}, \code{sX=s[4/6]},
+#'     \code{Y=7/6}, \code{sY=s[7/6]}, \code{rXY}
+#' 
+#' @rdname data2york
+#' @export
 data2york.ArAr <- function(x,inverse=TRUE,...){
     if (inverse)
         out <- ArAr.inverse.ratios(x)
@@ -210,6 +285,13 @@ data2york.ArAr <- function(x,inverse=TRUE,...){
     colnames(out) <- c('X','sX','Y','sY','rXY')
     out
 }
+#' @rdname data2york
+#' @export
+data2york.KCa <- function(x,...){
+    data2york(x$x,format=x$format,...)
+}
+#' @rdname data2york
+#' @export
 data2york.PbPb <- function(x,inverse=TRUE,...){
     if (inverse)
         out <- PbPb.inverse.ratios(x)
@@ -218,15 +300,21 @@ data2york.PbPb <- function(x,inverse=TRUE,...){
     colnames(out) <- c('X','sX','Y','sY','rXY')
     out
 }
-data2york.PD <- function(x,exterr=FALSE,common=FALSE,...){
+#' @param exterr If \code{TRUE}, propagates the external uncertainties
+#'     (e.g. decay constants) into the output errors.
+#' @rdname data2york
+#' @export
+data2york.PD <- function(x,exterr=FALSE,...){
     if (x$format==1){
         out <- x$x
     } else if (x$format==2){
-        out <- ppm2ratios(x,exterr=exterr,common=common)
+        out <- ppm2ratios(x,exterr=exterr)
     }
     colnames(out) <- c('X','sX','Y','sY','rXY')
     out
 }
+#' @rdname data2york
+#' @export
 data2york.UThHe <- function(x,...){
     ns <- length(x)
     out <- matrix(0,ns,5)
@@ -274,6 +362,26 @@ data2york.UThHe <- function(x,...){
     out[,'sY'] <- x[,'errHe']
     out
 }
+#' @param type Return `Rosholt' or `Osmond' ratios?
+#'
+#' Rosholt (\code{type=1}) returns \code{X=8/2}, \code{sX=s[8/2]},
+#' \code{Y=0/2}, \code{sY=s[0/2]}, \code{rXY}.
+#'
+#' Osmond (\code{type=2}) returns \code{X=2/8}, \code{sX=s[2/8]},
+#' \code{Y=0/8}, \code{sY=s[0/8]}, \code{rXY}.
+#'
+#' @param generic If \code{TRUE}, uses the following column headers:
+#'     \code{X}, \code{sX}, \code{Y}, \code{sY}, \code{rXY}.
+#'
+#' If \code{FALSE} and \code{type=1}, uses \code{U238Th232},
+#'     \code{errU238Th232}, \code{Th230Th232}, \code{errTh230Th232},
+#'     \code{rho}
+#'
+#' or if \code{FALSE} and \code{type=2}, uses \code{Th232U238},
+#'     \code{errTh232U238}, \code{Th230U238}, \code{errTh230U238},
+#'     \code{rho}.
+#' @rdname data2york
+#' @export
 data2york.ThU <- function(x,type=2,generic=TRUE,...){
     if (x$format %in% c(1,3) & type==1){
         out <- subset(x$x,select=c('U238Th232','errU238Th232',
